import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

// Data set URI
const csvUrl = [
  'https://gist.githubusercontent.com/',
  'happymail6/', // User
  'cd134b642115a7bff663865b0b0bbeb2/', // Id of the Gist
  'raw/b973000ac5b23b8f6ac95729a789a7d30c68aa04/', // commit
  'MCU.csv', // File name
].join('');
// Format the Data from the URI response
const parseRow = (d) => {
  d.IMDBrating = +d.IMDBrating;
  d.Metascore = +d.Metascore;
  d.Phase = +d.Phase;
  d.OscarNomination = +d.OscarNomination;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;

// Add SVG in the HTML body
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  //Loading data from CSV URI
  const data = await csv(csvUrl, parseRow);

  //Creating new scatterPlot object from helper fucntion
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(data)
    .xValue((d) => d.Metascore)
    .yValue((d) => d.IMDBrating)
    .margin({
      top: 60,
      right: 80,
      bottom: 60,
      left: 70,
    })
    .radius(5);
  	// Appending y label to the svg 
    svg.append("text")
    .attr("class", "y label")
    .attr("text-anchor", "end")
    .attr("y", 10)
    .attr("dy", ".65em")
    .attr("dx", "-5.65em")
    .attr("transform", "rotate(-90)")
    .attr("fill", "Blue")
    .attr("font-size", "30px")
    .attr("font-family", "Arial, Helvetica, sans-serif")
    .text("IMDBrating");
  	// Appending x label to the svg 
    svg.append("text")
    .attr("class", "x label")
    .attr("text-anchor", "end")
    .attr("x", width-450)
    .attr("y", height-10)
    .attr("fill", "Blue")
    .attr("font-size", "30px")
    .attr("font-family", "Arial, Helvetica, sans-serif")
    .text("Phase"); 
  
  //Appending plot scatter plot to svg html
  svg.call(plot);
  //declaring colmns from data file
  const columns = [
    'IMDBrating',
    'Phase',
    'OscarNomination',
    'Metascore',
  ];

  //Changing scatter plot x axis by a time interval
  let i = 0;
  setInterval(() => {
    plot.xValue(
      (d) => d[columns[i % columns.length]]
    );
  	// removing x label to the svg 
  	svg.select(".x.label").remove()
  	// appending again x label to the svg cuz to change petal width
    svg.append("text")
    .attr("class", "x label")
    .attr("text-anchor", "end")
    .attr("x", width-450)
    .attr("y", height-10)
    .attr("fill", "Blue")
    .attr("font-size", "30px")
    .attr("font-family", "Arial, Helvetica, sans-serif")
    .text(columns[i % columns.length]);     
    svg.call(plot);
    svg.append("text").attr("x", 450).attr("y", 20).text("MCU Scatter Plot").style("font-size", "35px").attr("alignment-baseline","middle").attr("fill", "Purple")
    i++;
  }, 1500);
};
main();
